@@ -52,6 +52,8 @@ def to_object(structure, obj_type=None):
                     setattr(obj, field, value)
             return obj
     else:
+        if structure is None or isinstance(structure, (bool, basestring, str, unicode, int, long, float, datetime.datetime)):
+            return structure
         if isinstance(structure, list):
             return [to_object(item) for item in structure]
         return Struct(structure)
